@@ -1,6 +1,7 @@
-package Email::MIME::Kit::Assembler::Standard;
+package Email::MIME::Kit::Assembler::Standard 3.000007;
 # ABSTRACT: the standard kit assembler
-$Email::MIME::Kit::Assembler::Standard::VERSION = '3.000005';
+
+use v5.20.0;
 use Moose;
 use Moose::Util::TypeConstraints;
 
@@ -365,7 +366,17 @@ Email::MIME::Kit::Assembler::Standard - the standard kit assembler
 
 =head1 VERSION
 
-version 3.000005
+version 3.000007
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 WARNING
 
@@ -383,7 +394,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2023 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
