@@ -1,6 +1,7 @@
-package Email::MIME::Kit::Role::Assembler;
+package Email::MIME::Kit::Role::Assembler 3.000007;
 # ABSTRACT: things that assemble messages (or parts)
-$Email::MIME::Kit::Role::Assembler::VERSION = '3.000006';
+
+use v5.20.0;
 use Moose::Role;
 with 'Email::MIME::Kit::Role::Component';
 
@@ -31,7 +32,17 @@ Email::MIME::Kit::Role::Assembler - things that assemble messages (or parts)
 
 =head1 VERSION
 
-version 3.000006
+version 3.000007
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 IMPLEMENTING
 
@@ -47,7 +58,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Ricardo Signes.
+This software is copyright (c) 2023 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
